#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-6IKSbZwyV3U5lGA6yJgapN
key:                  coinbase-pro-0.9.3.2-6IKSbZwyV3U5lGA6yJgapN
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  1db5834801016ed1b903002810baffde
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-6IKSbZwyV3U5lGA6yJgapN
depends:
    HsOpenSSL-0.11.7.9-F8EJ6CaUWi0DnuIuiUPBpz
    aeson-2.2.2.0-HX3VmpxSu7MBeXlY03a2B0
    aeson-casing-0.2.0.0-5dgL3tUH07H3jBK7caLlPS
    async-2.2.6-6oBfo7va0Nh7ISraaAL0Gg base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-7YTZu0l4p79JzK1Zrr6NNX exceptions-0.10.7
    http-api-data-0.6.1-E6BEj4druX86lEH66yAElM
    http-client-0.7.19-7W2xEySZC72756AXFfqUV4
    http-client-tls-0.3.6.4-PDqn3Ot8iJH3sGWMePnKH
    http-streams-0.8.9.9-14n1i1VG63sLthKwgLEGlM
    http-types-0.12.4-1JnQTH18RU0DibFo35M5JY
    io-streams-1.5.2.2-LEBaIkNtineBYlzSeR6MtL
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-D5In1g0c1o5Lno6WiKQzlZ
    servant-0.20.3.0-LVIw58LadumK5h6pSpU05P
    servant-client-0.20.3.0-GzMRNhSh2DYHMYH49u3lsD
    servant-client-core-0.20.3.0-GC653kP7hooDsVTRUz2Q3v
    tasty-1.5.3-6cV38PkEmA0CHSuZj5et2Y
    tasty-hunit-0.10.2-K8yXTSzPMzo5klyiFwnp6g text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-3DCCPamtk073AxQGVh94sj
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw
    uuid-1.3.16.1-DhWV9fEoepV648QL3EtyBy
    vector-0.13.2.0-DMZHGTdGAnaIWH7Z4Bo5hL
    websockets-0.12.7.3-FcL4ug6xJ2o87FujJej9qe
    wuss-2.0.1.7-FzdlyJWFNKv7ylRrzkEwtL

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

